#!/usr/bin/env perl

package main v0.1.0;

use Pcore;
use <: $module_name :>;

1;
__END__
=pod

=encoding utf8

=head1 REQUIRED ARGUMENTS

=over

=back

=head1 OPTIONS

=over

=back

=cut
